@@ -35,11 +35,11 @@ static WinResource *list_ne_type_resources (WinLibrary *, int *);
 static WinResource *list_ne_name_resources (WinLibrary *, WinResource *, int *);
 static WinResource *list_pe_resources (WinLibrary *, Win32ImageResourceDirectory *, int, int *);
 static int calc_vma_size (WinLibrary *);
-static void do_resources_recurs (WinLibrary *, WinResource *, WinResource *, WinResource *, WinResource *, char *, char *, char *, DoResourceCallback);
+static void do_resources_recurs (WinLibrary *, WinResource *, WinResource *, WinResource *, WinResource *, const char *, const char *, const char *, DoResourceCallback);
 static char *get_resource_id_quoted (WinResource *);
-static WinResource *find_with_resource_array(WinLibrary *, WinResource *, char *);
+static WinResource *find_with_resource_array(WinLibrary *, WinResource *, const char *);
 static WinResource *list_resources (WinLibrary *fi, WinResource *res, int *count);
-static bool compare_resource_id (WinResource *wr, char *id);
+static bool compare_resource_id (WinResource *wr, const char *id);
 
 /* Check whether access to a PE_SECTIONS is allowed */
 #define RETURN_IF_BAD_PE_SECTIONS(ret, module)                                              \
@@ -53,7 +53,7 @@ static bool compare_resource_id (WinResource *wr, char *id);
  */
 
 void
-do_resources (WinLibrary *fi, char *type, char *name, char *lang, DoResourceCallback cb)
+do_resources (WinLibrary *fi, const char *type, const char *name, const char *lang, DoResourceCallback cb)
 {
 	WinResource *type_wr;
 	WinResource *name_wr;
@@ -77,8 +77,8 @@ do_resources (WinLibrary *fi, char *type, char *name, char *lang, DoResourceCall
 
 static void
 do_resources_recurs (WinLibrary *fi, WinResource *base, WinResource *type_wr,
-                          WinResource *name_wr, WinResource *lang_wr,
-						  char *type, char *name, char *lang, DoResourceCallback cb)
+                     WinResource *name_wr, WinResource *lang_wr,
+                     const char *type, const char *name, const char *lang, DoResourceCallback cb)
 {
 	int c, rescnt;
 	WinResource *wr;
@@ -87,13 +87,9 @@ do_resources_recurs (WinLibrary *fi, WinResource *base, WinResource *type_wr,
 	wr = list_resources (fi, base, &rescnt);
 	if (wr == NULL)
 		return;
-	if (!check_offset(fi->memory, fi->total_size, fi->name, &wr[0], sizeof(WinResource)))
-		return;
 
 	/* process each resource listed */
 	for (c = 0 ; c < rescnt ; c++) {
-		if (!check_offset(fi->memory, fi->total_size, fi->name, &wr[c], sizeof(WinResource)))
-			break;
 		/* (over)write the corresponding WinResource holder with the current */
 		memcpy(WINRESOURCE_BY_LEVEL(wr[c].level), wr+c, sizeof(WinResource));
 
@@ -116,8 +112,9 @@ print_resources_callback (WinLibrary *fi, WinResource *wr,
                           WinResource *type_wr, WinResource *name_wr,
 						  WinResource *lang_wr)
 {
-	char *type, *offset;
-	int32_t id, size;
+	const char *type, *offset;
+	int32_t id;
+	size_t size;
 
 	/* get named resource type if possible */
 	type = NULL;
@@ -129,7 +126,7 @@ print_resources_callback (WinLibrary *fi, WinResource *wr,
 	if (offset == NULL)
 		return;
 
-	printf(_("--type=%s --name=%s%s%s [%s%s%soffset=0x%x size=%d]\n"),
+	printf(_("--type=%s --name=%s%s%s [%s%s%soffset=0x%x size=%zu]\n"),
 	  get_resource_id_quoted(type_wr),
 	  get_resource_id_quoted(name_wr),
 	  (lang_wr->id[0] != '\0' ? _(" --language=") : ""),
@@ -154,7 +151,7 @@ get_resource_id_quoted (WinResource *wr)
 }
 
 static bool
-compare_resource_id (WinResource *wr, char *id)
+compare_resource_id (WinResource *wr, const char *id)
 {
 	if (wr->numeric_id) {
 		int32_t cmp1, cmp2;
@@ -195,7 +192,7 @@ decode_pe_resource_id (WinLibrary *fi, WinResource *wr, uint32_t value)
 		wr->id[len] = '\0';
 	} else {					/* Unicode string id */
 		/* translate id into a string */
-		snprintf(wr->id, WINRES_ID_MAXLEN, "%d", value);
+		snprintf(wr->id, WINRES_ID_MAXLEN, "%" PRIu32, value);
 	}
 
 	wr->numeric_id = (value & IMAGE_RESOURCE_NAME_IS_STRING ? false:true);
@@ -203,7 +200,7 @@ decode_pe_resource_id (WinLibrary *fi, WinResource *wr, uint32_t value)
 }
  
 void *
-get_resource_entry (WinLibrary *fi, WinResource *wr, int *size)
+get_resource_entry (WinLibrary *fi, WinResource *wr, size_t *size)
 {
 	if (fi->is_PE_binary) {
 		Win32ImageResourceDataEntry *dataent;
@@ -317,7 +314,7 @@ list_ne_name_resources (WinLibrary *fi, WinResource *typeres, int *count)
 static WinResource *
 list_ne_type_resources (WinLibrary *fi, int *count)
 {
-	int c, rescnt;
+	size_t c, rescnt;
 	WinResource *wr;
 	Win16NETypeInfo *typeinfo;
 
@@ -487,7 +484,7 @@ static int
 calc_vma_size (WinLibrary *fi)
 {
     Win32ImageSectionHeader *seg;
-    int c, segcount, size;
+    size_t c, segcount, size;
 
     size = 0;
     RETURN_IF_BAD_POINTER(-1, PE_HEADER(fi->memory)->file_header.number_of_sections);
@@ -517,7 +514,7 @@ calc_vma_size (WinLibrary *fi)
 }
 
 static WinResource *
-find_with_resource_array(WinLibrary *fi, WinResource *wr, char *id)
+find_with_resource_array(WinLibrary *fi, WinResource *wr, const char *id)
 {
 	int c, rescnt;
 	WinResource *return_wr;
@@ -542,7 +539,7 @@ find_with_resource_array(WinLibrary *fi, WinResource *wr, char *id)
 }
 
 WinResource *
-find_resource (WinLibrary *fi, char *type, char *name, char *language, int *level)
+find_resource (WinLibrary *fi, const char *type, const char *name, const char *language, int *level)
 {
 	WinResource *wr;
 
